/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

import junit.framework.TestCase;
import org.apache.tools.ant.Location;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.Target;


/**
 * This class contains the unit tests for {@link AntTaskInfo}.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class AntTaskInfoTest extends TestCase {
    /**
     * This is a {@link org.apache.tools.ant.Project} instance used in test cases.
     */
    private static final Project PROJECT = new Project();
    /**
     * This is a task name used in test cases.
     */
    private static final String TASK_NAME = "taskName";
    /**
     * This is a {@link org.apache.tools.ant.Target} instance used in test cases.
     */
    private static final Target TARGET = new Target();
    /**
     * This is a {@link org.apache.tools.ant.Location} instance used in test cases.
     */
    private static final Location LOCATION = Location.UNKNOWN_LOCATION;
    /**
     * This is the instance to be tested. It is created in {@link #setUp()}.
     */
    private AntTaskInfo info;

    /**
     * This method tests {@link AntTaskInfo#AntTaskInfo(Project, String, Location, Target)} for correctness.
     */
    public void testCtor() {
        final AntTaskInfo instance = new AntTaskInfo(PROJECT, TASK_NAME, LOCATION, TARGET);
        assertEquals("constructor does not assign all fields", PROJECT, instance.getProject());
        assertEquals("constructor does not assign all fields", TASK_NAME, instance.getTaskName());
        assertEquals("constructor does not assign all fields", LOCATION, instance.getLocation());
        assertEquals("constructor does not assign all fields", TARGET, instance.getTarget());
    }

    /**
     * This method tests the correct failure behavior of {@link AntTaskInfo#AntTaskInfo(Project, String, Location,
     * Target)}.
     * <p/>
     * <b>Failure reason</b>: <tt>null</tt> project given
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testCtorFailNullProject() throws Exception {
        try {
            new AntTaskInfo(null, TASK_NAME, LOCATION, TARGET);
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link AntTaskInfo#AntTaskInfo(Project, String, Location,
     * Target)}.
     * <p/>
     * <b>Failure reason</b>: <tt>null</tt> taskName given
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testCtorFailNullTaskName() throws Exception {
        try {
            new AntTaskInfo(PROJECT, null, LOCATION, TARGET);
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link AntTaskInfo#AntTaskInfo(Project, String, Location,
     * Target)}.
     * <p/>
     * <b>Failure reason</b>: <tt>null</tt> location given
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testCtorFailNullLocation() throws Exception {
        try {
            new AntTaskInfo(PROJECT, TASK_NAME, null, TARGET);
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link AntTaskInfo#AntTaskInfo(Project, String, Location,
     * Target)}.
     * <p/>
     * <b>Failure reason</b>: <tt>null</tt> target given
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testCtorFailNullTarget() throws Exception {
        try {
            new AntTaskInfo(PROJECT, TASK_NAME, LOCATION, null);
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method tests the correct failure behavior of {@link AntTaskInfo#AntTaskInfo(Project, String, Location,
     * Target)}.
     * <p/>
     * <b>Failure reason</b>: empty task name given
     *
     * @throws Exception in case an unexpected Exception occurs
     */
    public void testCtorFailEmptyTaskName() throws Exception {
        try {
            new AntTaskInfo(PROJECT, "   ", LOCATION, TARGET);
            fail("should throw");
        } catch (IllegalArgumentException expected) {
            //expected
        }
    }

    /**
     * This method tests {@link AntTaskInfo#getProject()} for correctness.
     */
    public void testGetProject() {
        assertEquals(PROJECT, info.getProject());
    }

    /**
     * This method tests {@link AntTaskInfo#getLocation()} for correctness.
     */
    public void testGetLocation() {
        assertEquals(LOCATION, info.getLocation());
    }

    /**
     * This method tests {@link AntTaskInfo#getTaskName()} for correctness.
     */
    public void testGetTaskName() {
        assertEquals(TASK_NAME, info.getTaskName());
    }

    /**
     * This method tests {@link AntTaskInfo#getTarget()} for correctness.
     */
    public void testGetTarget() {
        assertEquals(TARGET, info.getTarget());
    }

    /**
     * This method does the test setup needed.
     *
     * @throws Exception in case some unexpected Exception occurs
     */
    protected void setUp() throws Exception {
        super.setUp();
        info = new AntTaskInfo(PROJECT, TASK_NAME, LOCATION, TARGET);
    }
}
