/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

/**
 * This is a mock class used in test cases. Its purpose is to have class that is of type {@link
 * com.topcoder.testframework.Server} and throws an exception when its one-arg constructor is called.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class DummyServerExceptionInConstructor extends Server {
    /**
     * This is the constructor which always throws an exception when called.
     *
     * @param type one arg
     *
     * @throws IllegalArgumentException always as test case scenario
     */
    public DummyServerExceptionInConstructor(final String type) {
        super(type);
        throw new IllegalArgumentException("This exception is the test case scenario.");
    }

    /**
     * This method starts the server. In the case when <tt>startserver</tt> attribute is set to <tt>false</tt>, the
     * server should not be started, but some initialization may still be needed. Subclasses must implement this method
     * to perform the actual task of starting up the server.
     *
     * @throws org.apache.tools.ant.BuildException
     *          if any error happens
     */
    public void startUp() {

    }

    /**
     * This method stops the server. The server should not be stopped if it wasn't started by the startUp() method, i.e.
     * <tt>startserver</tt> attribute is set to <tt>false</tt>. Subclasses must implement this method to perform the
     * actual task of stopping the server.
     *
     * @throws org.apache.tools.ant.BuildException
     *          if any error happens
     */
    public void shutDown() {

    }

    /**
     * This method initializes the server  with data. In the case when <tt>initserver</tt> attribute is set to
     * <tt>false</tt>, does nothing, or can check if the data are properly initialized, the implementation can choose
     * the preferred way. Subclasses must implement this method to perform the actual task of initializing server with
     * data.
     *
     * @throws org.apache.tools.ant.BuildException
     *          if any error happens
     */
    public void initData() {

    }

    /**
     * This method cleans up the data initialized by the {@link #initData()} method. In the case when
     * <tt>initserver</tt> attribute is set to <tt>false</tt> or data was not initialized, does nothing. Subclasses must
     * implement this method to perform the actual task of  cleaning-up the data.
     *
     * @throws org.apache.tools.ant.BuildException
     *          if any error happens
     */
    public void cleanUpData() {

    }
}
