/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.testframework;

/**
 * This class contains the unit tests for {@link com.topcoder.testframework.Server}.
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class ServerTest extends AbstractServerTest {

    /**
     * This method creates the instance to be tested by calling the constructor using the given type value as argument.
     *
     * @param type the type value to be used as constructor argument
     *
     * @return the instance created
     */
    protected Server createInstance(final String type) {
        return new MockServer(type);
    }

    /**
     * This is a mock class used to have an instantiatable Server subclass. It does not have any functionality besides
     * making the functionality defined in {@link Server} accessible to tests.
     */
    private static final class MockServer extends Server {
        /**
         * Creates a new MockServer with the specified type.
         *
         * @param type the type to be used
         */
        private MockServer(final String type) {
            super(type);
        }

        /**
         * Starts the server. In the case when <tt>startserver</tt> attribute is set to <tt>false</tt>, the server
         * should not be started, but some initialization may still be needed. Subclasses must implement this method to
         * perform the actual task of starting up the server.
         *
         * @throws org.apache.tools.ant.BuildException
         *          if any error happens
         */
        public void startUp() {
            //This method is intentionally empty
        }

        /**
         * Stops the server. The server should not be stopped if it wasn't started by the startUp() method, i.e.
         * <tt>startserver</tt> attribute is set to <tt>false</tt>. Subclasses must implement this method to perform the
         * actual task of stopping the server.
         *
         * @throws org.apache.tools.ant.BuildException
         *          if any error happens
         */
        public void shutDown() {
            //This method is intentionally empty
        }

        /**
         * Inits the server  with data. In the case when <tt>initserver</tt> attribute is set to <tt>false</tt>, does
         * nothing, or can check if the data are properly initialized, the implementation can choose the preferred way.
         * Subclasses must implement this method to perform the actual task of initializing server with data.
         *
         * @throws org.apache.tools.ant.BuildException
         *          if any error happens
         */
        public void initData() {
            //This method is intentionally empty
        }

        /**
         * Cleans up the data initialized by the initData() method. In the case when <tt>initserver</tt> attribute is
         * set to <tt>false</tt> or data was not initialized, does nothing. Subclasses must implement this method to
         * perform the actual task of  cleaning-up the data.
         *
         * @throws org.apache.tools.ant.BuildException
         *          if any error happens
         */
        public void cleanUpData() {
            //This method is intentionally empty
        }
    }
}
